//! Various implementations of [`crate::ShipBehavior`]

mod null;
mod point;

pub use null::*;
pub use point::Point;

use galactica_galaxy::GxShipHandle;
use rapier2d::dynamics::{RigidBodyHandle, RigidBodySet};
use std::collections::HashMap;

use crate::{
	objects::{ShipControls, SySimShip},
	StepResources,
};

/// Ship controller trait. Any struct that implements this
/// may be used to control a ship.
pub trait ShipController {
	/// Update a ship's controls based on system state.
	/// This method does not return anything, it modifies
	/// the ship's controls in-place.
	fn update_controls(
		&mut self,
		res: &StepResources,
		rigid_bodies: &RigidBodySet,
		ships: &HashMap<GxShipHandle, SySimShip>,
		this_ship: RigidBodyHandle,
		this_data: GxShipHandle,
	) -> ShipControls;
}
